@@ -18,10 +18,10 @@ app: typer.Typer = typer.Typer()
 
 app.command(name="create-registry")(create_registry)
 app.command(name="login")(login)
-app.command(name="create-app")(create_app)
+app.command(name="deploy")(create_app)
 app.command(name="set-default-subscription")(set_default_subscription)
 app.command(name="list-subscriptions")(list_subscriptions)
-app.command(name="create-database")(create_database)
+app.command(name="create-db")(create_database)
 
 
 @app.callback()
